==> gnue-common_0.5.4.1.orig.tar.gz: gnue-common-0.5.4.1/src/datasources/drivers/sqlrelay/sqlrelay/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("SQLRelay Python Client")
url = "http://sqlrelay.sourceforge.net/"
doc = """
Description
-----------
Python driver for SQLRelay.

Support
-------
Supported Platforms:

  - Linux/BSD
  - Solaris
  - MS Windows 98/NT/2000/XP

Connection Properties
---------------------
* host       -- This is the hostname of the server running SQLRealy (required)
* port       -- This is the port that SQLRelay is running on (defaults to 9000) (optional)

Examples
--------
  [myconn]
  provider=sqlrelay       # Use the SQLRelay adapter
  host=hostname           # The host running SQLRelay
  port=9000

Notes
-----
1. This driver has not been fully tested.  If you are successfully using
   this driver, please let us know.

2. This driver does not support schema introspection, so you will not
   be able to use Wizards in GNUe Designer.
"""

==> gnue-common_0.5.14.orig.tar.gz: gnue-common-0.5.14/src/datasources/drivers/sqlrelay/sqlrelay/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("SQLRelay Python Client")
url = "http://sqlrelay.sourceforge.net/"
doc = """
Description
-----------
Python driver for SQLRelay.

Support
-------
Supported Platforms:

  - Linux/BSD
  - Solaris
  - MS Windows 98/NT/2000/XP

Connection Properties
---------------------
* host       -- This is the hostname of the server running SQLRealy (required)
* port       -- This is the port that SQLRelay is running on (defaults to 9000) (optional)

Examples
--------
  [myconn]
  provider=sqlrelay       # Use the SQLRelay adapter
  host=hostname           # The host running SQLRelay
  port=9000

Notes
-----
1. This driver is currently unmaintained and not functional.
"""
